@@ -281,7 +281,7 @@ mod tests {
             account::{self, Account, AccountSharedData, WritableAccount},
             instruction::{AccountMeta, Instruction},
             keyed_account::KeyedAccount,
-            process_instruction::{mock_set_sysvar, MockInvokeContext},
+            process_instruction::MockInvokeContext,
             rent::Rent,
             stake::{
                 config as stake_config,
@@ -289,8 +289,9 @@ mod tests {
                 state::{Authorized, Lockup, StakeAuthorize},
             },
             sysvar::stake_history::StakeHistory,
+            sysvar_cache::SysvarCache,
         },
-        std::{cell::RefCell, rc::Rc, str::FromStr},
+        std::{borrow::Cow, cell::RefCell, str::FromStr},
     };
 
     fn create_default_account() -> RefCell<AccountSharedData> {
@@ -370,12 +371,12 @@ mod tests {
                 .collect();
 
             let mut invoke_context = MockInvokeContext::new(keyed_accounts);
-            mock_set_sysvar(
-                &mut invoke_context,
+            let mut sysvar_cache = SysvarCache::default();
+            sysvar_cache.push_entry(
                 sysvar::clock::id(),
-                sysvar::clock::Clock::default(),
-            )
-            .unwrap();
+                bincode::serialize(&Clock::default()).unwrap(),
+            );
+            invoke_context.sysvar_cache = Cow::Owned(sysvar_cache);
             super::process_instruction(&Pubkey::default(), &instruction.data, &mut invoke_context)
         }
     }
@@ -1038,12 +1039,12 @@ mod tests {
         ];
 
         let mut invoke_context = MockInvokeContext::new(keyed_accounts);
-        let clock = Clock::default();
-        let mut data = vec![];
-        bincode::serialize_into(&mut data, &clock).unwrap();
-        invoke_context
-            .sysvars
-            .push((sysvar::clock::id(), Some(Rc::new(data))));
+        let mut sysvar_cache = SysvarCache::default();
+        sysvar_cache.push_entry(
+            sysvar::clock::id(),
+            bincode::serialize(&Clock::default()).unwrap(),
+        );
+        invoke_context.sysvar_cache = Cow::Owned(sysvar_cache);
 
         assert_eq!(
             super::process_instruction(
